==> hashikake-0.3.3.zip: src/jp/gr/java_conf/ktz/puzzle/hashikake/creator/view/action/SaveAction.java <==
// ***************************************************************************************
//
//	Copyright (C) 2003 Kazuhiko TAMURA. All rights reserved.
//
//	This program is free software; you can redistribute it and/or 
//	modify it under the terms of the GNU General Public License
//	as published by the Free Software Foundation; either version 2
//	of the License, or (at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//	NAME:		SaveAction.java
//	DATE:		2003.8.2
//	CREATOR:	Kazuhiko TAMURA
//
// ***************************************************************************************

package jp.gr.java_conf.ktz.puzzle.hashikake.creator.view.action;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

import jp.gr.java_conf.ktz.puzzle.hashikake.view.CommandContainer;
import jp.gr.java_conf.ktz.puzzle.hashikake.view.AWTDispatchCommandQueue;

import jp.gr.java_conf.ktz.puzzle.hashikake.util.gui.Usherable;
import jp.gr.java_conf.ktz.puzzle.hashikake.util.gui.ComponentUsher;

import jp.gr.java_conf.ktz.puzzle.hashikake.creator.view.command.SaveIssueCommand;

public class SaveAction implements ActionListener {
	public void actionPerformed(ActionEvent inEvent) {
		Usherable aUsher = ComponentUsher.getInstance().getActiveComponent();
		if (aUsher instanceof CommandContainer) {
			CommandContainer aCommander = (CommandContainer)aUsher;
			SaveIssueCommand aCommand = new SaveIssueCommand(aCommander);

			AWTDispatchCommandQueue.postCommand(aCommand);
		}
	}
}

==> hashikake-0.4.0.zip: src/jp/gr/java_conf/ktz/puzzle/hashikake/creator/view/action/SaveAction.java <==
// ***************************************************************************************
//
//	Copyright (C) 2003 Kazuhiko TAMURA. All rights reserved.
//
//	This program is free software; you can redistribute it and/or 
//	modify it under the terms of the GNU General Public License
//	as published by the Free Software Foundation; either version 2
//	of the License, or (at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//	NAME:		SaveAction.java
//	DATE:		2003.8.2
//	CREATOR:	Kazuhiko TAMURA
//
// ***************************************************************************************

package jp.gr.java_conf.ktz.puzzle.hashikake.creator.view.action;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

import jp.gr.java_conf.ktz.puzzle.hashikake.view.CommandContainer;
import jp.gr.java_conf.ktz.puzzle.hashikake.view.AWTDispatchCommandQueue;

import jp.gr.java_conf.ktz.puzzle.hashikake.util.gui.Usherable;
import jp.gr.java_conf.ktz.puzzle.hashikake.util.gui.ComponentUsher;

import jp.gr.java_conf.ktz.puzzle.hashikake.creator.view.command.SaveIssueCommand;

public class SaveAction implements ActionListener {
	public void actionPerformed(ActionEvent inEvent) {
		Usherable aUsher = ComponentUsher.getInstance().getActiveComponent();
		if (aUsher instanceof CommandContainer) {
			CommandContainer aCommander = (CommandContainer)aUsher;
			SaveIssueCommand aCommand = new SaveIssueCommand(aCommander, false);

			AWTDispatchCommandQueue.postCommand(aCommand);
		}
	}
}
